# kerasAC
keras accessibility models

To install the module:

pip install -e kerasAC

To train a model: **kerasAC_train**

To predict on a test dataset: **kerasAC_predict**

To interpret a model: **kerasAC_interpret**

To run n-fold cross validation for training/ prediction / interpretation: **kerasAC_cross_validate** 

see "scripts" folder for example parameters to use with each of these functionalities
